package engine.r;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JPanel;

import org.rosuda.JRI.REXP;
import org.rosuda.JRI.RFactor;
import org.rosuda.JRI.RVector;
import org.rosuda.JRI.Rengine;
import org.rosuda.javaGD.JGDBufferedPanel;

import model.ChisqTest;
import model.Table;
import engine.Engine;

/**
 * Provides methods for data analysis in R language
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public class R_engine implements Engine {
	
	/**
	 * Variable for JavaGD canvas  
	 */
	public static JGDBufferedPanel jgdBuffPanel = new JGDBufferedPanel(400, 300);
	
	private Rengine rengine;
	private JPanel plotGraphPanel;

	private String versionOS;

	/**
	 * Create and initialize R engine. 
	 * 
	 * @throws Exception - exception for fail R load
	 */
	public R_engine() throws Exception{
		System.out.print("creating Engine...");
		rengine = new Rengine (new String [] {"--vanilla"}, false, null);
		
		if (!rengine.waitForR())
		{
			System.out.println ("Cannot load R");
			throw new Exception("Cannot load R");
		}
		System.out.println("..done");
		
		versionOS = System.getProperty("os.name");
		
		rengine.eval("library(JavaGD)");
		rengine.eval("library(plotrix)");
		rengine.eval("options(digits=4)");

		plotGraphPanel = R_engine.jgdBuffPanel;
	}
	
	@Override
	public void histogram(String colName, Integer breaks, HIST_TYPES type){
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR){
			return;
		}
		
		String breaksStr = "'Sturges'";
		if(breaks != null) breaksStr = breaks.toString();
		
		if(type == HIST_TYPES.NORM){
			rengine.eval("his"+colName+" <- hist(data$"+colName+", breaks="+breaksStr+", plot=F)");
		}
		else if(type == HIST_TYPES.LOG){
			rengine.eval("his"+colName+" <- hist(log(data$"+colName+"), breaks="+breaksStr+", plot=F)");
		}
	}
	
	private void initPlot(){
		rengine.eval(".setenv <- if (exists('Sys.setenv')) Sys.setenv else Sys.putenv");
        rengine.eval(".setenv('JAVAGD_CLASS_NAME'='engine/r/PlotGDInterface')");
        rengine.eval("JavaGD(width=400, height=300)");
	}
	
	@Override
	public void createBoxPlot(String title, String ... colNames){
		initPlot();
		
		String cols = "";
		for (int i = 0; i < colNames.length; i++) {
			cols += "data$"+colNames[i];
			if (i != colNames.length-1) {
				cols +=",";
			}
		}
		
		String colsShort = "";
		for (int i = 0; i < colNames.length; i++) {
			colsShort += "'"+colNames[i]+"'";
			if (i != colNames.length-1) {
				colsShort +=",";
			}
		}
		
		rengine.eval("boxplot("+cols+", col=plotColors, names=c("+colsShort+"), main='"+title+"', notch=TRUE)");
		
		if(colNames.length == 1){
			rengine.eval("for(i in 1:length(summary(data$"+colNames[0]+"))){"
					+ "mtext(paste(names(summary(data$"+colNames[0]+")[i]), summary(data$"+colNames[0]+")[i], sep=': '), side = 3, line = -i, adj=1)}"
					);
		}
		
		rengine.eval("plotColors <- NA");
	}
	
	@Override
	public void createBarPlot(PLOT_TYPES type, String title, String xLabel, String yLabel, String ... colNames){
		initPlot();
		
        if(colNames.length == 1){
        	if(rengine.eval("data$"+colNames[0]).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colNames[0]).getType() == REXP.XT_FACTOR){
        		if (type == PLOT_TYPES.ABS) {
        			rengine.eval("bp <- barplot(table(data$"+colNames[0]+"), col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE)");
        			rengine.eval("text(bp, 0, table(data$"+colNames[0]+"),cex=1,pos=3)");
        		}
        		else if (type == PLOT_TYPES.REL) {
        			rengine.eval("bp <- barplot(prop.table(table(data$"+colNames[0]+")), col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE)");
        			rengine.eval("text(bp, 0, prop.table(table(data$"+colNames[0]+")),cex=1,pos=3)");
        		}
        		else if (type == PLOT_TYPES.REL100) {
        			rengine.eval("bp <- barplot(prop.table(table(data$"+colNames[0]+"))*100, col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE)");
        			rengine.eval("text(bp, 0, paste(prop.table(table(data$"+colNames[0]+")*100), '%', sep=''),cex=1,pos=3)");
        		}
    		}
        	else{
        		double[] breaks = rengine.eval("his"+colNames[0]+"$breaks").asDoubleArray();
    			String breaksName = "";
    			for (int i = 0; i < breaks.length-1; i++) {
    				breaksName += "'"+breaks[i]+"-"+breaks[i+1]+"'";
    				if(i != breaks.length-2) breaksName += ",";
    			}
    			
        		if (type == PLOT_TYPES.ABS) {
        			rengine.eval("bp <- barplot(his"+colNames[0]+"$counts, col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE, names = c("+breaksName+"))");
        			rengine.eval("text(bp, 0, his"+colNames[0]+"$counts,cex=1,pos=3)");
        		}
        		else if (type == PLOT_TYPES.REL) {
        			rengine.eval("bp <- barplot(his"+colNames[0]+"$counts / sum(his"+colNames[0]+"$counts), col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE, names=c("+breaksName+"))");
        			rengine.eval("text(bp, 0, his"+colNames[0]+"$counts / sum(his"+colNames[0]+"$counts),cex=1,pos=3)");
        		}
        		else if (type == PLOT_TYPES.REL100) {
        			rengine.eval("bp <- barplot((his"+colNames[0]+"$counts / sum(his"+colNames[0]+"$counts))*100, col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE, names=c("+breaksName+"))");
        			rengine.eval("text(bp, 0, (his"+colNames[0]+"$counts / sum(his"+colNames[0]+"$counts)*100),cex=1,pos=3)");
        		}
        	}
        }
        else{
			rengine.eval("barplot(cont, col=plotColors, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', beside=TRUE)");
        }
		
		
		
		rengine.eval("plotColors <- NA");
	}
	
	@Override
	public boolean createHistogram(PLOT_TYPES type, String title, String xLabel, String yLabel, String colName){
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			return false;
		}
		initPlot();
		if (type == PLOT_TYPES.ABS) {
			rengine.eval("plot(his"+colName+", xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', col=plotColors)");
		}
		else if (type == PLOT_TYPES.REL){
			rengine.eval("hisTmp <- his"+colName);
			rengine.eval("hisTmp$counts <- his"+colName+"$counts / sum(his"+colName+"$counts)");
			rengine.eval("plot(hisTmp, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', col=plotColors)");
		}
		else if (type == PLOT_TYPES.REL100){
			rengine.eval("hisTmp <- his"+colName);
			rengine.eval("hisTmp$counts <- (his"+colName+"$counts / sum(his"+colName+"$counts))*100");
			rengine.eval("plot(hisTmp, xlab='"+xLabel+"', ylab='"+yLabel+"', main='"+title+"', col=plotColors)");
		}
		rengine.eval("plotColors <- NA");
		return true;
	}
	
	@Override
	public void createPiePlot(PLOT_TYPES type, String title, String colName){
		initPlot();
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			if (type == PLOT_TYPES.ABS) {
				rengine.eval("pie3D(table(data$"+colName+"), labels=paste(levels(factor(data$"+colName+")),table(data$"+colName+"),sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
			}
			else if (type == PLOT_TYPES.REL){
				rengine.eval("pie3D(prop.table(table(data$"+colName+")), labels=paste(levels(factor(data$"+colName+")),prop.table(table(data$"+colName+")),sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
			}
			else if (type == PLOT_TYPES.REL100){
				rengine.eval("pie3D(prop.table(table(data$"+colName+"))*100, labels=paste(levels(factor(data$"+colName+")),paste(prop.table(table(data$"+colName+"))*100,'%'),sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
			}
		}
		else{
    		double[] breaks = rengine.eval("his"+colName+"$breaks").asDoubleArray();
			String breaksName = "";
			for (int i = 0; i < breaks.length-1; i++) {
				breaksName += "'"+breaks[i]+"-"+breaks[i+1]+"'";
				if(i != breaks.length-2) breaksName += ",";
			}
			
    		if (type == PLOT_TYPES.ABS) {
				rengine.eval("pie3D(his"+colName+"$counts, labels=paste(c("+breaksName+"),his"+colName+"$counts,sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
    		}
    		else if (type == PLOT_TYPES.REL) {
				rengine.eval("pie3D(his"+colName+"$counts / sum(his"+colName+"$counts), labels=paste(c("+breaksName+"),his"+colName+"$counts / sum(his"+colName+"$counts),sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
    		}
    		else if (type == PLOT_TYPES.REL100) {
				rengine.eval("pie3D((his"+colName+"$counts / sum(his"+colName+"$counts))*100, labels=paste(c("+breaksName+"),paste((his"+colName+"$counts / sum(his"+colName+"$counts)*100),'%'),sep='\n'), col=plotColors, main='"+title+"',height=0.1, start=pi/4, theta=pi/4, explode=0.1, labelcex=1)");
    		}
    	}
		
		rengine.eval("plotColors <- NA");
	}
	
	@Override
	public String[] getDefaultCategories(String colName){
		REXP e = rengine.eval("levels(factor(data$"+colName+"))");
		return e.asStringArray();	
	}
	
	@Override
	public String[] getCategories(String colName){
		if(rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			REXP e = rengine.eval("levels(data$"+colName+")");
			return e.asStringArray();
		}
		else if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR){
			REXP e = rengine.eval("levels(factor(data$"+colName+"))");
			return e.asStringArray();
		}
		else{
			REXP cat = rengine.eval("his"+colName+"$breaks");
			double[] breaks = cat.asDoubleArray();
			String[] breaksName = new String[breaks.length-1];
			for (int i = 0; i < breaksName.length; i++) {
				breaksName[i] = ""+breaks[i]+" - "+breaks[i+1];
			}
			return breaksName;
		}
		
	}
	
	@Override
	public Table getTable(){	
		int[] dimmension = rengine.eval("dim(data)").asIntArray();
		
		Table table = new Table(dimmension[0], dimmension[1]);
		
		RVector vector = rengine.eval("data").asVector();
		
		for (int i = 0; i < vector.size(); i++) {
			
			if(vector.at(i).getType() == REXP.XT_ARRAY_INT) {
				int[] vec = vector.at(i).asIntArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(""+vec[j], j, i);
				}
			}
			if(vector.at(i).getType() == REXP.XT_ARRAY_DOUBLE){
				double[] vec = vector.at(i).asDoubleArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(""+vec[j], j, i);
				}
			}
			if(vector.at(i).getType() == REXP.XT_ARRAY_STR){
				String[] vec = vector.at(i).asStringArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(vec[j], j, i);
				}
			}
		}
		
		table.setNames(rengine.eval("names(data)").asStringArray());
		
		return table;
	}
	
	@Override
	public Table getTable(String[] columnNames){
		int[] dimmension = rengine.eval("dim(data)").asIntArray();
		
		Table table = new Table(dimmension[0], columnNames.length);
		
		for (int i = 0; i < columnNames.length; i++) {
			REXP data = rengine.eval("data$"+columnNames[i]);
			
			if(data.getType() == org.rosuda.JRI.REXP.XT_ARRAY_INT) {
				int[] vec = data.asIntArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(""+vec[j], j, i);
				}
			}
			if(data.getType() == org.rosuda.JRI.REXP.XT_ARRAY_DOUBLE){
				double[] vec = data.asDoubleArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(""+vec[j], j, i);
				}
			}
			if(data.getType() == org.rosuda.JRI.REXP.XT_ARRAY_STR){
				data.asFactor();
				String[] vec = data.asStringArray();
				for (int j = 0; j < vec.length; j++) {
					table.setData(vec[j], j, i);
				}
			}
			if(data.getType() == REXP.XT_FACTOR){
				RFactor factor = data.asFactor();
				for (int j = 0; j < factor.size(); j++) {
					table.setData(""+factor.at(j), j, i);
				}
			}
		}
		
		table.setNames(columnNames);
		
		return table;
	}

	@Override
	public void changeCategoriesNames(String[] values, String colName){
		String vector = "'";
		for (int i = 0; i < values.length; i++) {
			vector += values[i] + "'";
			if(i != values.length-1){
				vector += ",'";
			}
		}
		rengine.eval("levels(data$"+colName+") <- c("+vector+")");
	}

	@Override
	public boolean loadTable(String filePath, FILE_TYPE fileType){
		if(versionOS.contains("Windows")){
			filePath = filePath.replace("\\", "/");
		}
		rengine.eval("options(stringsAsFactors = FALSE)");
		rengine.eval("plotColors <- NA");
		
		switch (fileType) {
		case COMMA:
			rengine.eval("data <- read.table('"+filePath+"', header=T, sep=',')");
			return rengine.eval("data").getType() != REXP.XT_NULL;

		case SEMICOLON:
			rengine.eval("data <- read.table('"+filePath+"', header=T, sep=';')");
			return rengine.eval("data").getType() != REXP.XT_NULL;
		}
		return false;
		
	}

	@Override
	public void savePlots(String filePath, int width, int height){
		if(versionOS.contains("Windows")){
			filePath = filePath.replace("\\", "/");
		}
		rengine.eval("dev.print(png, file = '"+filePath+"', width ="+width+", height ="+height+")");
	}

	@Override
	public void setColors(String[] colors){
		String vector = "'";
		for (int i = 0; i < colors.length; i++) {
			vector += colors[i] + "'";
			if(i != colors.length-1){
				vector += ",'";
			}
		}
		rengine.eval("plotColors <- c("+vector+")");
	}

	@Override
	public void setNAValue(String value, String colName){
		rengine.eval("data$"+colName+"[data$"+colName+" == '"+value+"'] <- NA");
	}
	
	@Override
	public boolean convertVariable(String colName, VAR_TYPES convert){
		if(convert == VAR_TYPES.FACTOR){
			rengine.eval("data$"+colName+" <- as.character(data$"+colName+")");
			return true;
		}
		else if(convert == VAR_TYPES.NUM){
			
			rengine.eval("tmp <- data$"+colName);
			rengine.eval("tmp <- gsub('\\\\s', '', tmp)");
			rengine.eval("data$"+colName+"<- as.numeric(tmp)");
			return true;
		}
		return false;
	}

	@Override
	public JPanel getPlotGraphPanel() {
		return plotGraphPanel;
	}

	@Override
	public void setPlotGraphPanel(JPanel plotGraphPanel) {
		this.plotGraphPanel = plotGraphPanel;
	}

	@Override
	public Table getContingencyTable(String colName1, String colName2) {
		String first = "data$"+colName1;
		String second = "data$"+colName2;
		
		if(rengine.eval("data$"+colName1).getType() != REXP.XT_ARRAY_STR){
			first = "cut(data$"+colName1+", breaks=his"+colName1+"$breaks, include.lowest=T)";
		}
		if(rengine.eval("data$"+colName2).getType() != REXP.XT_ARRAY_STR){
			second = "cut(data$"+colName2+", breaks=his"+colName2+"$breaks, include.lowest=T)";
		}
		
		String[] yNames;
		String[] zNames;
		
		REXP data = rengine.eval("cont <- table("+first+", "+second+")");
		double[][] matrix = data.asMatrix();
		
		data = rengine.eval("labels(cont)");
		RVector vector = data.asVector();
		yNames = vector.at(0).asStringArray();
		zNames = vector.at(1).asStringArray();
		
		Table contTable = new Table(matrix.length, matrix[0].length+1);
		for (int i = 0; i < matrix.length; i++) {
			for (int j = -1; j < matrix[0].length; j++) {
				if(j == -1){
					contTable.setData(yNames[i], i, 0);
				}
				else{
					contTable.setData(String.format("%.2f", matrix[i][j]), i, j+1);
				}
			}
		}
		String[] names = new String[zNames.length+1];
		names[0] = "";
		for (int i = 0; i < zNames.length; i++) {
			names[i+1] = zNames[i];
		}
		contTable.setNames(names);
		
		return contTable;
	}

	@Override
	public ChisqTest chisqDependencyTest() {
		REXP data = rengine.eval("chisq.test(cont)");
		RVector vector = data.asVector();
		String result = "";
		result += "X^2 = "+vector.at(0).asDouble()+"\n";
		result += "v(df) = "+vector.at(1).asInt()+"\n";
		double pValue = vector.at(2).asDouble();
		result += "p-value = "+pValue+"\n";
		
		boolean success;
		
		if(pValue <= 0.05){
			success = false;
		}
		else{
			success = true;
		}
			
		return new ChisqTest(result, success);
	}

	@Override
	public Table getCharacteristicTable(String ...cols) {
		Table table = new Table(cols.length, 9);
		table.setNames(new String[] {"Mo", "v", "nomvar", "H","Mean", "R", "IRQ", "Var","s"});
		
		for (int i = 0; i < cols.length; i++){
			String col = cols[i];
			String sModCat = "-", sV = "-", sNomvar = "-", sH = "-", sMean = "-", sR = "-", sIrq = "-", sVar = "-", sS = "-";
			
			if(rengine.eval("data$"+col).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+col).getType() == REXP.XT_FACTOR){
				rengine.eval("relative <- prop.table(table(data$"+col+"))");
			}
			else{
				REXP mean = rengine.eval("mean(na.omit(data$"+col+"))");
				REXP r = rengine.eval("max(na.omit(data$"+col+"))-min(na.omit(data$"+col+"))");
				REXP irq = rengine.eval("quantile(data$"+col+", na.rm = TRUE)[4]-quantile(data$"+col+", na.rm = TRUE)[2]");
				REXP var = rengine.eval("var(na.omit(data$"+col+"))");
				REXP s = rengine.eval("sd(na.omit(data$"+col+"))");
				
				if(mean.getType()==REXP.XT_ARRAY_INT){
					sMean = ""+mean.asInt();
				}
				else {
					sMean = ""+mean.asDouble();
				}
				if(r.getType()==REXP.XT_ARRAY_INT){
					sR = ""+r.asInt();
				}
				else {
					sR = ""+r.asDouble();
				}
				if(irq.getType()==REXP.XT_ARRAY_INT){
					sIrq = ""+irq.asInt();
				}
				else {
					sIrq = ""+irq.asDouble();
				}
				if(var.getType()==REXP.XT_ARRAY_INT){
					sVar = ""+var.asInt();
				}
				else {
					sVar = ""+var.asDouble();
				}
				if(s.getType()==REXP.XT_ARRAY_INT){
					sS = ""+s.asInt();
				}
				else {
					sS = ""+s.asDouble();
				}
				
				rengine.eval("relative <- his"+col+"$counts / sum(his"+col+"$counts)");
			}
			
			rengine.eval("mo <- relative[relative == max(relative)]");
			REXP modCat = rengine.eval("mo");
			REXP v = rengine.eval("1-mo");		
			REXP nomvar = rengine.eval("1-sum(relative^2)");
			REXP h = rengine.eval("-sum(relative*log(relative))");
			
			
			if(modCat.getType()==REXP.XT_ARRAY_INT){
				sModCat = ""+modCat.asInt();
			}
			else {
				sModCat = String.format("%.2f", modCat.asDouble());
			}
			if(v.getType()==REXP.XT_ARRAY_INT){
				sV = ""+v.asInt();
			}
			else {
				sV = String.format("%.2f", v.asDouble());
			}
			if(nomvar.getType()==REXP.XT_ARRAY_INT){
				sNomvar = ""+nomvar.asInt();
			}
			else {
				sNomvar = String.format("%.2f", nomvar.asDouble());
			}
			if(h.getType()==REXP.XT_ARRAY_INT){
				sH = ""+h.asInt();
			}
			else {
				sH = String.format("%.2f", h.asDouble());
			}
			
			table.setData(sModCat, i, 0);
			table.setData(sV, i, 1);
			table.setData(sNomvar, i, 2);
			table.setData(sH, i, 3);
			table.setData(sMean, i, 4);
			table.setData(sR, i, 5);
			table.setData(sIrq, i, 6);
			table.setData(sVar, i, 7);
			table.setData(sS, i, 8);
		}
			
		return table;
	}
	
	/**
	 * Compute and return R representation absolute frequency.
	 * 
	 * @param colName String - column name
	 * @return REXP - R object with relative absolute data
	 */
	private REXP computeAbsoluteFrequency(String colName){
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			return rengine.eval("table(data$"+colName+")");
		}
		else{
			return rengine.eval("his"+colName+"$counts");
		}	
	}
	
	/**
	 * Compute and return R representation cumulative frequency.
	 * 
	 * @param colName String - column name
	 * @return REXP - R object with relative cumulative data
	 */
	private REXP computeCumulativeFrequency(String colName){
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			return rengine.eval("cumsum(prop.table(table(data$"+colName+")))");
		}
		else{
			return rengine.eval("cumsum(his"+colName+"$counts / sum(his"+colName+"$counts))");
		}
	}
	
	/**
	 * Compute and return R representation relative frequency.
	 * 
	 * @param colName String - column name
	 * @param percent boolean - true if result is in %, false otherwise
	 * @return REXP - R object with relative frequency data
	 */
	private REXP computeRelativeFrequency(String colName, boolean percent){
		String param = percent ? "*100" : "";
		
		if(rengine.eval("data$"+colName).getType() == REXP.XT_ARRAY_STR || rengine.eval("data$"+colName).getType() == REXP.XT_FACTOR){
			return rengine.eval("prop.table(table(data$"+colName+"))"+param);
		}
		else{
			return rengine.eval("his"+colName+"$counts / sum(his"+colName+"$counts)"+param);
		}
	}
	
	@Override
	public Table getFrequencyTable(String colName) {
		String [] cat = getCategories(colName);
		int[] abs = computeAbsoluteFrequency(colName).asIntArray();
		double[] rel = computeRelativeFrequency(colName, false).asDoubleArray();
		double [] cum = computeCumulativeFrequency(colName).asDoubleArray();
		
		Table table = new Table(cat.length, 5);
		table.setNames(new String[] {"k","Nk","Pk","Pk[%]","CumSum"});
		for (int i = 0; i < cat.length; i++) {
			for (int j = 0; j < 5; j++) {
				switch (j) {
				case 0:
					table.setData(cat[i], i, j);
					break;
				case 1:
					table.setData(""+abs[i], i, j);
					break;
				case 2:
					table.setData(String.format("%.2f", rel[i]), i, j);
					break;
				case 3:
					table.setData(String.format("%.2f", rel[i]*100), i, j);
					break;
				case 4:
					table.setData(String.format("%.2f", cum[i]), i, j);
					break;
				default:
					break;
				}
			}
		}	
		
		return table;
	}
	
	/**
	 * Compute and return R representation of quantile table.
	 * 
	 * @param colName String - column name
	 * @return REXP - R object with quantile table data
	 */
	private REXP getQuantiles(String colName){
		return rengine.eval("quantile(data$"+colName+", na.rm=TRUE)");
	}

	@Override
	public Table getQuantileTable(String... cols) {
		List<String> numCols = new ArrayList<String>();
		for (int i = 0; i < cols.length; i++) {
			if(rengine.eval("data$"+cols[i]).getType() != REXP.XT_ARRAY_STR && rengine.eval("data$"+cols[i]).getType() != REXP.XT_FACTOR){
				numCols.add(cols[i]);
			}
		}
		
		if(numCols.size() == 0) return null;
		
		Table table = new Table(numCols.size(), 6);
		table.setNames(new String[]{"","0%","25%","50%","75%","100%"});
		
		for (int i = 0; i < numCols.size(); i++) {
			table.setData(numCols.get(i), i, 0);
			double[] val = getQuantiles(numCols.get(i)).asDoubleArray();
			for (int j = 0; j < val.length; j++) {
				table.setData(String.format("%.2f", val[j]), i, j+1);
			}
			
		}
		return table;
	}
}