package gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import javax.swing.ButtonGroup;
import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTabbedPane;
import javax.swing.JTable;

import model.Table;
import utils.ExportUtils;
import utils.FileUtils;
import utils.Language;
import engine.Engine;
import gui.components.Button;
import gui.components.CheckBoxMenuItem;
import gui.components.Label;
import gui.components.Menu;
import gui.components.MenuItem;
import gui.components.RadioButtonMenuItem;
import gui.components.TitleBorder;
import gui.dialog.AnalyzeOptionsDialog;
import gui.dialog.ChiSqDialog;
import gui.model.MyTableModel;
import gui.panels.FreqPlotPanel;
import gui.panels.QuartPlotPanel;

/** 
 * Frame with specific columns from source data.
 * Frame with options for view result of data analysis, 
 * and for export this results.
 * 
 * This frame is specific variant from base class {@link MainFrame}.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public class DetailFrame extends MainFrame{
	
	private static final long serialVersionUID = 1L;
	
	private String[] columnName;
	private String[] newColumnName;
	private List<String> analyzeVariable;
	private Map<String, Table> freqMap;
	private Map<String, Table> quartMap;
	private Map<String, Table> characterMap;
	private Map<String, Integer> analyzeOptions;
	protected boolean edit, group = false;
	private model.Boolean newWindow = new model.Boolean(true);
	
	private Menu menuConfigPlot;
	private Menu menuExport;
	private Menu menuOptions;
	private CheckBoxMenuItem menuItemCfgPlotWindow;
	private MenuItem menuItemsAnalyze;
	private MenuItem menuItemPlotGroup;
	private MenuItem menuItemExportPlot;
	private MenuItem menuItemExportFreqTable;	
	private JTable table;
	private MyTableModel modelTable;	
	private Label lblBox1;
	private Label lblBox2;
	private JButton btnOK;
	private JComboBox<String> box1;
	private JComboBox<String> box2;
	private JTabbedPane centerPanel;
	protected FreqPlotPanel groupPlot;
	private TitleBorder freqBorder;
	private TitleBorder groupBorder;
	private TitleBorder quartBorder;
	private JPanel groupPanel;
	private MenuItem menuItemExportQuartTable;
	protected JScrollPane scrollGroupTable;
	private Button btnTest;
	private TitleBorder characterBorder;
	private MenuItem menuItemExportCharTable;
	private Menu menuConfigHistogram;
	private RadioButtonMenuItem menuItemCfgHistDefault;
	private RadioButtonMenuItem menuItemCfgHistLog;
	private MenuItem menuItemPlotCrosstable;

	private JPanel groupTablePanel;
	
	/**
	 * Create frame with specific columns from data table, 
	 * language and engine for data analyze.
	 * 
	 * @param engine {@link Engine} - engine for data analyze
	 * @param lang {@link Language} - language for load labels
	 * @param columnName String[] - specific columns names
	 * @throws IOException - Exception for invalid language, or invalid language file
	 */
	public DetailFrame(Engine engine, Language lang, String[] columnName) throws IOException {
		super(engine, lang);
		
		analyzeVariable = new ArrayList<String>();
		freqMap = new HashMap<String, Table>();
		quartMap = new HashMap<String, Table>();
		characterMap = new HashMap<String, Table>();
		newColumnName = new String[1];
		for (String string : columnName) {
			analyzeVariable.add(string);
		}
		
		this.columnName = columnName;
		
		initGui();
		initListeners();
		
		pack();
		setVisible(true);
	}
	
	/**
	 * Create main GUI elements
	 */
	private void initGui() {
		setPreferredSize(new Dimension(600, 600));
		centerPanel = new JTabbedPane();
		
		createMenu();
		createDataTable();
		
		add(centerPanel, BorderLayout.CENTER);
	}
	
	/**
	 * Create additional menu things
	 */
	private void createMenu() {

		//new menus
		menuOptions = new Menu("MENU_OPTIONS", language);
		addObject(menuOptions);
		menuBar.add(menuOptions);
		
		//config submenus
		menuConfigPlot = new Menu("MENU_CONFIG_PLOT", language);
		addObject(menuConfigPlot);
		menuConfig.add(menuConfigPlot);
		menuConfigHistogram = new Menu("MENU_CONFIG_HIST", language);
		addObject(menuConfigHistogram);
		menuConfig.add(menuConfigHistogram);
		
		//config plot menu items
		menuItemCfgPlotWindow = new CheckBoxMenuItem("MENU_CONFIG_PLOT_WINDOW", language);
		menuItemCfgPlotWindow.setSelected(true);
		addObject(menuItemCfgPlotWindow);
		menuConfigPlot.add(menuItemCfgPlotWindow);
		
		//config histogram menu items
		menuItemCfgHistDefault = new RadioButtonMenuItem("MENU_CONFIG_HIST_DEFAULT", language);
		menuItemCfgHistDefault.setSelected(true);
		addObject(menuItemCfgHistDefault);
		menuConfigHistogram.add(menuItemCfgHistDefault);
		menuItemCfgHistLog = new RadioButtonMenuItem("MENU_CONFIG_HIST_LOG", language);
		addObject(menuItemCfgHistLog);
		menuConfigHistogram.add(menuItemCfgHistLog);
		ButtonGroup group = new ButtonGroup();
		group.add(menuItemCfgHistDefault);
		group.add(menuItemCfgHistLog);
		
		//options menu items
		menuItemsAnalyze = new MenuItem("MENU_OPTIONS_ANALYZE", language);
		addObject(menuItemsAnalyze);
		menuItemPlotGroup = new MenuItem("MENU_OPTIONS_PLOTGROUP", language);
		menuItemPlotGroup.setEnabled(false);
		addObject(menuItemPlotGroup);
		menuItemPlotCrosstable = new MenuItem("MENU_OPTIONS_PLOTCROSS", language);
		menuItemPlotCrosstable.setEnabled(false);
		addObject(menuItemPlotCrosstable);
		menuOptions.add(menuItemsAnalyze);
		menuOptions.add(menuItemPlotGroup);
		menuOptions.add(menuItemPlotCrosstable);
		
		//file menu items and submenus
		menuExport = new Menu("MENU_FILE_EXPORT", language);
		addObject(menuExport);
		menuFile.add(menuExport);
		
		//export menu items
		menuItemExportPlot = new MenuItem("MENU_FILE_EXPORT_PLOT", language);
		addObject(menuItemExportPlot);
		menuItemExportPlot.setEnabled(false);
		menuItemExportFreqTable = new MenuItem("MENU_FILE_EXPORT_TABLE_FREQ", language);
		menuItemExportQuartTable = new MenuItem("MENU_FILE_EXPORT_TABLE_QUART", language);
		menuItemExportCharTable = new MenuItem("MENU_FILE_EXPORT_TABLE_CHAR", language);
		addObject(menuItemExportFreqTable);
		addObject(menuItemExportQuartTable);
		addObject(menuItemExportCharTable);
		menuExport.add(menuItemExportPlot);
		menuExport.add(menuItemExportFreqTable);
		menuExport.add(menuItemExportQuartTable);
		menuExport.add(menuItemExportCharTable);
	}
	
	/**
	 * Create first tab which contains table with 
	 * specified variables in DataFrame
	 */
	private void createDataTable() {
		modelTable = new MyTableModel(engine.getTable(columnName));
		int colsNum = modelTable.getColumnCount();
		table = new JTable(modelTable);
		JScrollPane scroll = new JScrollPane(table);
		scroll.setPreferredSize(new Dimension(colsNum*150,500));
		centerPanel.addTab("Data", scroll);
	}
	
	/**
	 * Create additional listeners
	 */
	private void initListeners(){
		menuItemExportCharTable.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				Table table = characterMap.get(centerPanel.getTitleAt(centerPanel.getSelectedIndex()));
				if(table != null){
					ExportUtils.exportTableToCSV(table, FileUtils.showFileSaveDialog("CSV file", "csv"));
				}
				else{
					return;
				}
			}
		});
		
		menuItemExportCharTable.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportCharTable.getNotes());
			}
		});
		
		menuItemExportFreqTable.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				Table table = freqMap.get(centerPanel.getTitleAt(centerPanel.getSelectedIndex()));
				if(table != null){
					ExportUtils.exportTableToCSV(table, FileUtils.showFileSaveDialog("CSV file", "csv"));
				}
				else{
					return;
				}
				
			}
		});
		
		menuItemExportQuartTable.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				Table table = quartMap.get(centerPanel.getTitleAt(centerPanel.getSelectedIndex()));
				if(table != null){
					ExportUtils.exportTableToCSV(table, FileUtils.showFileSaveDialog("CSV file", "csv"));
				}
				else{
					return;
				}
			}
		});
		
		menuItemsAnalyze.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				analyzeOptions = null;
				analyzeOptions = AnalyzeOptionsDialog.showDialog(analyzeVariable.toArray(newColumnName), langProp);
				if(analyzeOptions == null) return;
				
				int index = analyzeOptions.get(AnalyzeOptionsDialog.VARIABLE);
				if(index == -1) return;
				
				createAnalyzeGroup1(analyzeVariable.get(index));
				createAnalyzeGroup2(analyzeVariable.get(index));

				
				analyzeVariable.remove(analyzeVariable.get(index));
				
				if(analyzeVariable.isEmpty()){
					menuItemsAnalyze.setEnabled(false);
					menuItemPlotGroup.setEnabled(true);
					menuItemPlotCrosstable.setEnabled(true);
				}
				
				pack();
			}			
		});
		
		
		menuItemPlotGroup.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				JPanel panel = new JPanel();
				panel.setLayout(new BorderLayout());
				
				panel.add(createCharacterPanel(columnName), BorderLayout.CENTER);
				JPanel quartP = createQuartPanel(columnName);
				if(quartP != null) panel.add(quartP, BorderLayout.SOUTH);
				
				centerPanel.add("Summary", panel);
				
				menuItemPlotGroup.setEnabled(false);
				
				pack();
			}
		});
		
		menuItemPlotCrosstable.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				createCrossTable();
				
				menuItemPlotCrosstable.setEnabled(false);
			}
		});
		
		menuItemsAnalyze.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemsAnalyze.getNotes());
			}
		});
		
		menuItemPlotGroup.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemPlotGroup.getNotes());
			}
		});
		
		menuItemCfgPlotWindow.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				newWindow.setValue(menuItemCfgPlotWindow.isSelected());
				menuItemExportPlot.setEnabled(!menuItemCfgPlotWindow.isSelected());
			}
		});
		
		menuItemCfgPlotWindow.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemCfgPlotWindow.getNotes());
			}
		});
		
		menuItemExportPlot.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				String path = FileUtils.showFileSaveDialog("PNG file", "png");
				if(path != null){
					engine.savePlots(path+".png", engine.getPlotGraphPanel().getWidth(), engine.getPlotGraphPanel().getWidth());
				}
			}
		});
		
		menuItemExportPlot.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportPlot.getNotes());
			}
		});
		
		menuExport.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuExport.getNotes());
			}
		});
		
		menuItemExportFreqTable.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportFreqTable.getNotes());
			}
		});
		
		menuItemExportQuartTable.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportQuartTable.getNotes());
			}
		});
		
		menuOptions.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuOptions.getNotes());
			}
		});
		
		menuConfigPlot.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuConfigPlot.getNotes());
			}
		});
		
		menuConfigHistogram.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuConfigHistogram.getNotes());
			}
		});
		
		menuItemCfgHistDefault.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemCfgHistDefault.getNotes());
			}
		});
		
		menuItemCfgHistLog.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemCfgHistLog.getNotes());
			}
		});
		
		menuItemPlotCrosstable.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemPlotCrosstable.getNotes());
			}
		});
	}
	
	/**
	 * Create tab for first group of analysis methods 
	 * for specific column (Frequency table, histogram plots)
	 * 
	 * @param col String - specific column name
	 */
	private void createAnalyzeGroup1(String col) {
		Integer breaks = null;
		JPanel freqPanel = null;
		FreqPlotPanel freqPlotPanel = null;
		
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		
		if(analyzeOptions.get(AnalyzeOptionsDialog.GROUP1_HIST_USER).intValue() == AnalyzeOptionsDialog.SELECT) breaks = analyzeOptions.get(AnalyzeOptionsDialog.HIST_BREAKS);
		
		if(menuItemCfgHistLog.isSelected()) engine.histogram(col, breaks, Engine.HIST_TYPES.LOG);
		else engine.histogram(col, breaks, Engine.HIST_TYPES.NORM);
		
		//Create frequency table panel------------------------------
		if(analyzeOptions.get(AnalyzeOptionsDialog.GROUP1_FREQUENCY_TABLE).intValue() == AnalyzeOptionsDialog.SELECT){
			freqPanel = new JPanel(new BorderLayout());
			freqBorder = new TitleBorder("LABEL_FREQ", language);
			addObject(freqBorder);
			freqPanel.setBorder(freqBorder);
			
			Table freqTable = engine.getFrequencyTable(col);
			MyTableModel model = new MyTableModel(freqTable);
			JTable freqGuiTable = new JTable(model);
			freqMap.put(col, freqTable);
			freqGuiTable.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
			JScrollPane scroll = new JScrollPane(freqGuiTable);
			//scroll.setPreferredSize(new Dimension(400,150));
			
			freqPanel.add(scroll, BorderLayout.CENTER);
		}
		
		//Create plotPanel---------------------------------------------
		if(analyzeOptions.get(AnalyzeOptionsDialog.GROUP1_HIST).intValue() == AnalyzeOptionsDialog.SELECT){
			freqPlotPanel = new FreqPlotPanel(engine, language, this, col);
			freqPlotPanel.setNewWindow(newWindow);
			addObject(freqPlotPanel);
			freqPlotPanel.getBtnDraw().addMouseListener(new MouseAdapter() {
				@Override
				public void mouseEntered(MouseEvent arg0) {
					statusBar.setStatusText(langProp.getProperty("DESC_BUTTON_DRAW"));
				}
			});
		}
		
		//-------------------------------------------------------------
		if(freqPanel == null && freqPlotPanel == null) return;
		
		if(freqPanel != null) panel.add(freqPanel, BorderLayout.CENTER);
		if(freqPlotPanel != null && freqPanel == null) panel.add(freqPlotPanel, BorderLayout.CENTER);
		else if(freqPlotPanel != null)panel.add(freqPlotPanel, BorderLayout.SOUTH);
		centerPanel.add(col, panel);
		
	}
	
	/**
	 * Create tab for second group of analysis methods 
	 * for specific column (characteristic table, quantile table)
	 * 
	 * @param col String - specific column name
	 */
	private void createAnalyzeGroup2(String col) {
		JPanel charPanel = null, kvantPanel = null;
		
		//create characteristic panel-----------------------------------
		if(analyzeOptions.get(AnalyzeOptionsDialog.GROUP2_CHARACTER_TABLE).intValue() == AnalyzeOptionsDialog.SELECT){
			 charPanel = createCharacterPanel(col);
		}
		
		//create kvantile panel------------------------------------------
		if(analyzeOptions.get(AnalyzeOptionsDialog.GROUP2_KVANTILE_TABLE).intValue() == AnalyzeOptionsDialog.SELECT){
			kvantPanel = createQuartPanel(col);
		}
		
		if(charPanel == null && kvantPanel == null) return;
		
		JPanel panel = new JPanel();
		panel.setLayout(new BorderLayout());
		
		if(charPanel != null) panel.add(charPanel, BorderLayout.CENTER);
		if(kvantPanel != null && charPanel == null) panel.add(kvantPanel, BorderLayout.CENTER);
		else if(kvantPanel != null) panel.add(kvantPanel, BorderLayout.SOUTH);
		centerPanel.add(col, panel);
	}
	
	/**
	 * Create tab for contingency table
	 */
	private void createCrossTable(){
		DetailFrame parent = this;
		
		//create choose panel------------------------------
		lblBox1 = new Label("LABEL_GROUP_FIRST", language);
		addObject(lblBox1);
		box1 = new JComboBox<String>(columnName);
		lblBox2 = new Label("LABEL_GROUP_SECOND", language);
		addObject(lblBox2);
		box2 = new JComboBox<String>(columnName);
		btnOK = new JButton("ok");
		btnTest = new Button("BUTTON_TEST", language);
		btnTest.setEnabled(false);
		addObject(btnTest);
		
		JPanel chooseGroupPanel = new JPanel(new FlowLayout());
		chooseGroupPanel.add(lblBox1);
		chooseGroupPanel.add(box1);
		chooseGroupPanel.add(lblBox2);
		chooseGroupPanel.add(box2);
		chooseGroupPanel.add(btnOK);
		chooseGroupPanel.add(btnTest);
		
		//Table panel----------------------------------------
		
		groupTablePanel = new JPanel();
		groupTablePanel.setLayout(new BorderLayout());

		//Final add-------------------------------------------
		groupPanel = new JPanel();
		groupPanel.setLayout(new BorderLayout());
		groupPanel.add(chooseGroupPanel, BorderLayout.NORTH);
		groupPanel.add(groupTablePanel, BorderLayout.CENTER);
		
		groupBorder = new TitleBorder("LABEL_GROUP", language);
		addObject(groupBorder);
		groupPanel.setBorder(groupBorder);
		
		centerPanel.add("Group", groupPanel);
		
		pack();
		
		//init listeners----------------------------------
				btnOK.addActionListener(new ActionListener() {
					@Override
					public void actionPerformed(ActionEvent arg0) {
						if (groupPlot != null) {
							groupTablePanel.remove(scrollGroupTable);
							groupPanel.remove(groupPlot);
							freqMap.remove("Group");
						}
						
						Table contTable = engine.getContingencyTable((String)box1.getSelectedItem(),(String)box2.getSelectedItem());
						MyTableModel model = new MyTableModel(contTable);
						JTable groupTable = new JTable(model);
						freqMap.put("Group", contTable);
						groupTable.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
						scrollGroupTable = new JScrollPane(groupTable);
						scrollGroupTable.setPreferredSize(new Dimension(300, 100));
						groupTablePanel.add(scrollGroupTable);
						
						groupPlot = new FreqPlotPanel(engine, language, parent, (String)box1.getSelectedItem(),(String)box2.getSelectedItem());
						groupPlot.setPieDisable();
						groupPlot.setNewWindow(newWindow);
						groupPanel.add(groupPlot, BorderLayout.SOUTH);
						pack();
						btnTest.setEnabled(true);
					}
				});
				btnOK.addMouseListener(new MouseAdapter() {
					@Override
					public void mouseEntered(MouseEvent arg0) {
						statusBar.setStatusText(langProp.getProperty("DESC_BUTTON_OK"));
					}
				});
				
				btnTest.addActionListener(new ActionListener() {
					
					@Override
					public void actionPerformed(ActionEvent arg0) {
						try {
							new ChiSqDialog(engine.chisqDependencyTest(), langProp.getProperty("DESC_BUTTON_TEST")).setVisible(true);
						} catch (IOException e) {
							// TODO Auto-generated catch block
							e.printStackTrace();
						}
					}
				});
				btnTest.addMouseListener(new MouseAdapter() {
					@Override
					public void mouseEntered(MouseEvent arg0) {
						statusBar.setStatusText(langProp.getProperty("DESC_BUTTON_TEST"));
					}
				});
	}
	
	/**
	 * Create panel with characteristic table
	 * for specific columns
	 * 
	 * @param col String - columns names
	 * @return characteristicPanel JPanel
	 */
	private JPanel createCharacterPanel(String ... col){
		
		JPanel characterPanel = new JPanel(new BorderLayout());
		characterBorder = new TitleBorder("LABEL_CHAR", language);
		addObject(characterBorder);
		characterPanel.setBorder(characterBorder);
		
		Table charTable = engine.getCharacteristicTable(col);		
		if(charTable != null){
			if(col.length != 1){		
				characterMap.put("Summary", charTable);
			}
			else{
				characterMap.put(col[0], charTable);
			}
			
			MyTableModel model = new MyTableModel(charTable);
			JTable charGuiTable = new JTable(model);
			charGuiTable.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
			JScrollPane scroll = new JScrollPane(charGuiTable);
			//scroll.setPreferredSize(new Dimension(500,100));
			
			characterPanel.add(scroll, BorderLayout.CENTER);
		}
		
		return characterPanel;
	}
	
	/**
	 * Create panel with qunatile table
	 * for specific columns
	 * 
	 * @param col String - columns names
	 * @return qunatilePanel JPanel
	 */
	private JPanel createQuartPanel(String ... cols){	
		String tag = "Summary";
		
		Table quartTable = engine.getQuantileTable(cols);
		
		if(quartTable == null) return null;
		
		if(quartTable.getRowCount() == 1){
			tag = quartTable.getData(0, 0);
		}
		
		MyTableModel model = new MyTableModel(quartTable);
		
		JTable quartGuiTable = new JTable(model);
		quartMap.put(tag, quartTable);
		quartGuiTable.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
		JScrollPane scroll = new JScrollPane(quartGuiTable);
		scroll.setPreferredSize(new Dimension(500,100));
		
		JPanel quartPanel = new JPanel();
		quartPanel.setLayout(new BorderLayout());
		
		quartBorder = new TitleBorder("LABEL_QUART", language);
		addObject(quartBorder);
		quartPanel.setBorder(quartBorder);

		QuartPlotPanel quartPlotPanel = new QuartPlotPanel(engine, language, this, model.getCol(0));
		quartPlotPanel.setNewWindow(newWindow);
		addObject(quartPlotPanel);
		quartPlotPanel.getBtnDraw().addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(langProp.getProperty("DESC_BUTTON_DRAW"));
			}
		});
		
		quartPanel.add(scroll, BorderLayout.CENTER);
		quartPanel.add(quartPlotPanel, BorderLayout.SOUTH);

		return quartPanel;
	}
	
	/**
	 * Return option for plotPanel. If it is TRUE, plotPanel will be 
	 * create in new Window. If it is false, plotPanel will be create
	 * in application window
	 * 
	 * @return TRUE if menuItemCfgPlotWindow is selected, FALSE otherwise
	 */
	public boolean isNewWindowSelected(){
		return menuItemCfgPlotWindow.isSelected();
	}
	
	@Override
	protected void closeWindow() {
		dispose();
	}

}
