package gui;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.io.IOException;

import engine.Engine;
import gui.components.Menu;
import gui.components.MenuItem;
import utils.FileUtils;
import utils.Language;

/**
 * Frame with plot canvas and plot export menus.
 * 
 * This frame is specific variant from base class {@link MainFrame}.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class PlotFrame extends MainFrame {
	
	private static final long serialVersionUID = 1L;
	
	private Menu menuExport;
	private MenuItem menuItemExportPlot;
	
	/**
	 * Create frame with specific columns from data table, 
	 * language and engine for data analyze.
	 * 
	 * @param engine {@link Engine} - engine for data analyze
	 * @param lang {@link Language} - language for load labels
	 * @throws IOException - Exception for invalid language, or invalid language file
	 */
	public PlotFrame(Engine engine, Language lang) throws IOException {
		super(engine, lang);
		
		setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		
		createMenu();
		initListeners();
	}
	
	/** 
	 * Create additional menus.
	 */
	private void createMenu() {
		menuExport = new Menu("MENU_FILE_EXPORT", language);
		menuItemExportPlot = new MenuItem("MENU_FILE_EXPORT_PLOT", language);
		menuExport.add(menuItemExportPlot);
		addObject(menuItemExportPlot);
		menuFile.add(menuExport);
		addObject(menuExport);
	}
	
	/**
	 * Create additional listeners.
	 */
	private void initListeners() {
		menuItemExportPlot.addActionListener(new ActionListener() {
			
			@Override
			public void actionPerformed(ActionEvent arg0) {
				String path = FileUtils.showFileSaveDialog("PNG file", "png");
				if(path != null){
					engine.savePlots(path, getWidth(), getHeight());
				}
			}
		});
		
		menuItemExportPlot.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportPlot.getNotes());
			}
		});
		
		menuExport.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseEntered(MouseEvent arg0) {
				statusBar.setStatusText(menuItemExportPlot.getNotes());
			}
		});
	}

	@Override
	protected void closeWindow() {
		dispose();
	}
	
}
