package gui.components;
import utils.Language;

/**
 * Interface for gui objects. Contains methods for
 * dynamic changes of their texts.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public interface GuiObject {

	/**
	 * Loads and replace language texts
	 * 
	 * @param lang {@link Language}
	 */
	public void fireLabels(Language lang);
	
	/**
	 * Get actual language 
	 * 
	 * @return lang {@link Language}
	 */
	public Language getLanguage();
	
	/**
	 * Get text of this object
	 * 
	 * @return name String
	 */
	public String getName();
	
	/**
	 * Get description of this object
	 * 
	 * @return description String
	 */
	public String getNotes();

	/**
	 * Set other language
	 * 
	 * @param language {@link Language}
	 */
	public void setLanguage(Language language);

}