package gui.components;
import java.io.IOException;
import java.util.Properties;

import utils.Language;
import utils.LanguageUtils;

/**
 * This class represent Title border gui object. 
 * It extends from TitledBorder
 * and implements {@link GuiObject} interface.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public class TitleBorder extends javax.swing.border.TitledBorder implements GuiObject {

	private static final long serialVersionUID = 1L;
	
	private String id;
	private Properties langProp = new Properties();
	private Language language;
	private String name;
	private String notes = null;

	/**
	 * Create instance of new Title border with specific 
	 * string{@link String} id (location in language file) and 
	 * specific language {@link Language}.
	 * 
	 * @param id String - location in language file
	 * @param lang {@link Language} - specific language
	 */
	public TitleBorder(String id, Language lang){
		super("");
		this.id = id;
		this.language = lang;
		fireLabels(language);
		setTitle(name);
	}

	@Override
	public void fireLabels(Language lang){
		this.language = lang;
		openLangFile();
		name = langProp.getProperty(id);
		setTitle(name);
	}
	
	@Override
	public Language getLanguage(){
		return language;
	}
	
	@Override
	public String getName(){
		return name;
	}
	
	@Override
	public String getNotes(){
		return notes;
	}
	
	/**
	 * Open and load language file
	 */
	private void openLangFile(){
		try {
			langProp.load(LanguageUtils.openLangFile(language));
		} catch (IOException e) {
			e.printStackTrace();
		}
	}

	@Override
	public void setLanguage(Language language){
		this.language = language;
	}
}