package gui.dialog;

import java.awt.BorderLayout;
import java.io.IOException;

import gui.components.Label;
import gui.components.TitleBorder;

import javax.swing.JDialog;
import javax.swing.JPanel;
import javax.swing.JTextArea;

import utils.LanguageUtils;
import model.ChisqTest;

/**
 * Modal dialog with results from Chi-sq test.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class ChiSqDialog extends JDialog {

	private static final long serialVersionUID = 1L;
	private ChisqTest test;
	
	/**
	 * Create Chi-sq test dialog.
	 * 
	 * @param test {@link ChisqTest} - structure with results of test
	 * @param title String - dialog title
	 * @throws IOException - language file exceptions
	 */
	public ChiSqDialog(ChisqTest test, String title) throws IOException {
		this.test = test;
		
		setModal(true);
		setTitle(title);
		setResizable(false);
		
		createGui();
		pack();
	}
	
	/**
	 * Create gui structure
	 * 
	 * @throws IOException - language file exceptions
	 */
	private void createGui() throws IOException {
		JPanel titlePanel = new JPanel();
		titlePanel.setBorder(new TitleBorder("DIALOG_CHISQ_TITLE_BORDER",LanguageUtils.getLanguage()));	
		Label lblTitle = new Label(test.isSuccess() ? "DIALOG_CHISQ_SUCCESS" : "DIALOG_CHISQ_FAIL", LanguageUtils.getLanguage());
		titlePanel.add(lblTitle);
		
		JPanel notesPanel = new JPanel();
		notesPanel.setBorder(new TitleBorder("DIALOG_CHISQ_PARAMETERS_BORDER",LanguageUtils.getLanguage()));
		JTextArea lblNotes = new JTextArea(test.getNotes());
		lblNotes.setEditable(false);
		lblNotes.setFont(lblTitle.getFont());
		notesPanel.add(lblNotes);
		
		add(titlePanel, BorderLayout.NORTH);
		add(notesPanel, BorderLayout.CENTER);
	}
}
