package gui.dialog;

import gui.components.TitleBorder;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.IOException;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JList;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ListSelectionModel;

import utils.LanguageUtils;

/**
 * Modal dialog for defined missing category.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class ChooseNADialog extends JDialog{

	private static final long serialVersionUID = 1L;
	private String[] levels;
	private String value = null;
	private JList<String> list;
	private JButton button;;
	
	/**
	 * Private constructor for dialog. For create and show 
	 * dialog use static method showDialog().
	 * 
	 * @param levels String[] - levels for specific column
	 * @param title String - dialog title
	 * @throws IOException - language file exceptions
	 */
	private ChooseNADialog(String[] levels, String title) throws IOException {
		super();
		setTitle(title);
		setModal(true);
		
		this.levels = levels;
		
		createGUI();
	}

	/**
	 * Create gui structure.
	 * 
	 * @throws IOException - language file exceptions
	 */
	private void createGUI() throws IOException {
		setPreferredSize(new Dimension(200,300));
		setLayout(new BorderLayout());
		setResizable(false);
		
		JPanel centerPanel = new JPanel(new BorderLayout());
		TitleBorder centerBorder = new TitleBorder("DIALOG_NA_BORDER_CHOOSEMISSING", LanguageUtils.getLanguage());
		list = new JList<>(levels);
		list.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		button = new JButton("OK");
		button.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent arg0) {
				value = list.getSelectedValue();
				dispose();
			}
		});
		
		JScrollPane scrollPane = new JScrollPane(list);
		
		centerPanel.add(scrollPane, BorderLayout.CENTER);
		centerPanel.add(button, BorderLayout.SOUTH);
		centerPanel.setBorder(centerBorder);
		
		add(centerPanel, BorderLayout.CENTER);
		pack();
	}
	
	/**
	 * Return name of missing category
	 * @return value String - category name
	 */
	public String getValue() {
		return value;
	}
	
	/**
	 * Create and show dialog. It return missing category name.
	 * 
	 * @param levels String[] - levels for specific column
	 * @param title String - dialog title
	 * @return value String - missing category name
	 * @throws IOException - language file exceptions
	 */
	public static String showDialog(String levels[], String title) throws IOException{
		ChooseNADialog dialog = new ChooseNADialog(levels, title);
		dialog.setVisible(true);
		
		return dialog.getValue();
	}
}
