package gui.model;

import javax.swing.table.AbstractTableModel;

/**
 * Table model for choosing colors.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class ColorTableModel extends AbstractTableModel{
	
	private static final long serialVersionUID = 1L;
	private String[] names;
	private String[] values;
	private String[] colors;
	
	/**
	 * Create table model.
	 * 
	 * @param values String[] - categories names 
	 * @param names String[] - columns names
	 */
	public ColorTableModel(String[] values, String[] names) {
		this.values = values;
		this.names = names;
		colors = new String[values.length];
		
		for (int i = 0; i < values.length; i++) {
			colors[i] = "white";
		}
	}
	
	@Override
	public int getColumnCount() {
		return names.length;
	}

	@Override
	public int getRowCount() {
		return values.length;
	}

	@Override
	public Object getValueAt(int row, int col) {
		switch (col) {
		case 0:
			return values[row];
		case 1:
			return colors[row];
		default:
			return null;
		}
	}
	
	@Override
	public boolean isCellEditable(int rowIndex, int columnIndex) {
		return false;
	}
	
	@Override
    public String getColumnName(int column) {
        return names[column];
    }

    @Override
    public Class<?> getColumnClass(int columnIndex) {
    	return String.class;
	}
    
    /**
     * Set specific color name.
     * 
     * @param row int - row index
     * @param color String - color name
     */
    public void setColor(int row, String color){
    	colors[row] = color;
    }
    
    /**
     * Return array with colors names.
     * 
     * @return String[] - colors names
     */
    public String[] getColors(){
    	return colors;
    }
}
