package gui.model;

import javax.swing.table.AbstractTableModel;

import model.Table;

/**
 * Universal table model for class {@link Table}.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class MyTableModel extends AbstractTableModel{
	
	private static final long serialVersionUID = 1L;
	private Table table;
	private int editableCol = -1;
	
	/**
	 * Create table model.
	 * 
	 * @param table {@link Table} - specific table
	 */
	public MyTableModel(Table table){
		this.table = table;
	}
	
	@Override
	public int getColumnCount() {
		return table.getColCount();
	}

	@Override
	public int getRowCount() {
		return table.getRowCount();
	}

	@Override
	public Object getValueAt(int row, int col) {
		return table.getData(row, col);
	}
	
	@Override
    public String getColumnName(int column) {
        return table.getNames()[column];
    }

    @Override
    public Class<?> getColumnClass(int columnIndex) {
    	if(columnIndex == 0) return String.class;
    	else return String.class;
    }

	@Override
	public boolean isCellEditable(int rowIndex, int columnIndex) {
		if (columnIndex == editableCol) {
			return true;
		}
		return false;
	}
	
	@Override
	public void setValueAt(Object aValue, int rowIndex, int columnIndex) {
		table.setData((String)aValue,rowIndex,columnIndex);
	}
	
    /**
     * Return all data from table.
     * 
     * @return String[][] - data from all table cells
     */
	public String[][] getData() {
		return table.getData();
	}   
	
	/**
	 * Return all columns names.
	 * 
	 * @return String[] - all columns names
	 */
	public String[] getNames() {
		return table.getNames();
	}   
	
	/**
	 * Return all data from specific column.
	 * 
	 * @param col int - column index
	 * @return colData String[] - data from column
	 */
	public String[] getCol(int col){
		String[] colData = new String[getRowCount()];
		for (int i = 0; i < getRowCount(); i++) {
			colData[i] = table.getData(i, col);
		}
		return colData;
	}
	
	/**
	 * Return all data from specific row.
	 * 
	 * @param row int - column index
	 * @return rowData String[] - data from row
	 */
	public String[] getRow(int row){
		String[] rowData = new String[getColumnCount()];
		for (int i = 0; i < getColumnCount(); i++) {
			rowData[i] = table.getData(row, i);
		}
		return rowData;
	}
	
	/**
	 * Set specific column to editable.
	 * 
	 * @param col int - column index
	 */
	public void setEditable(int col){
		editableCol = col;
	}
}
