package gui.panels;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import gui.model.ColorTableModel;

import javax.swing.JMenuItem;
import javax.swing.JPanel;
import javax.swing.JPopupMenu;
import javax.swing.JScrollPane;
import javax.swing.JTable;

/**
 * Represent panel with color table and 
 * popup menu with colors names to change.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class ChooseColorPanel extends JPanel {
	
	private static final long serialVersionUID = 1L;
	private String[] data;
	private String[] names;
	private String chooseColor;
	private ColorTableModel tableModel;
	private JTable table;

	private JPopupMenu popup;
	private JMenuItem menuBlack;
	private JMenuItem menuRed;
	private JMenuItem menuGreen;
	private JMenuItem menuBlue;
	private JMenuItem menuCyan;
	private JMenuItem menuMagneta;
	private JMenuItem menuYellow;
	private JMenuItem menuGray;
	private JMenuItem menuWhite;

	/**
	 * Create panel with table and popup menu.
	 * 
	 * @param data String[] - categories names
	 * @param names String[] - names for color table cols
	 */
	public ChooseColorPanel(String[] data, String[] names) {
		this.data = data;
		this.names = names;
		
		createPopupMenu();
		createGUI();
	}
	
	/**
	 * Create basic gui components
	 */
	private void createGUI() {		
		tableModel = new ColorTableModel(data, names);
		table = new JTable(tableModel);
		table.setAutoResizeMode(JTable.AUTO_RESIZE_ALL_COLUMNS);
		table.addMouseListener(new MouseAdapter() {
			@Override
			public void mouseClicked(MouseEvent e) {
				if(e.getButton() == 3 && table.getSelectedRow()!= -1){
					popup.show(((JTable) e.getComponent()), e.getX(), e.getY());
				}
			}
		});
		JScrollPane scrollPane = new JScrollPane(table);
		scrollPane.setPreferredSize(new Dimension(200,150));
		
		add(scrollPane, BorderLayout.CENTER);
	}
	
	/**
	 * Create popup menu.
	 */
	private void createPopupMenu(){
		popup = new JPopupMenu();
		menuBlack = new JMenuItem("black");
		menuBlack.addActionListener(new PopupActionListener());
		menuRed = new JMenuItem("red");
		menuRed.addActionListener(new PopupActionListener());
		menuGreen = new JMenuItem("green");
		menuGreen.addActionListener(new PopupActionListener());
		menuBlue = new JMenuItem("blue");
		menuBlue.addActionListener(new PopupActionListener());
		menuCyan = new JMenuItem("cyan");
		menuCyan.addActionListener(new PopupActionListener());
		menuMagneta = new JMenuItem("magenta");
		menuMagneta.addActionListener(new PopupActionListener());
		menuYellow = new JMenuItem("yellow");
		menuYellow.addActionListener(new PopupActionListener());
		menuGray = new JMenuItem("gray");
		menuGray.addActionListener(new PopupActionListener());
		menuWhite = new JMenuItem("white");
		menuWhite.addActionListener(new PopupActionListener());
		
		popup.add(menuBlack);
		popup.add(menuBlue);
		popup.add(menuCyan);
		popup.add(menuGray);
		popup.add(menuGreen);
		popup.add(menuMagneta);
		popup.add(menuRed);
		popup.add(menuYellow);
		popup.add(menuWhite);
	}
	
	/**
	 * Return array with colors for all categories.
	 * 
	 * @return colors String[] - categories colors
	 */
	public String[] getColors(){
    	return tableModel.getColors();
    }
	
	/**
	 * Change categories names in color table.
	 * 
	 * @param data String - categories names
	 */
	public void fireDataList(String[] data){
		tableModel = new ColorTableModel(data, names);
		table.setModel(tableModel);
	}
	
	/**
	 * Inner class for custom popup listener.
	 * 
	 * @author Pavel Vojtas
	 *
	 */
	public class PopupActionListener implements ActionListener{
		@Override
		public void actionPerformed(ActionEvent e) {
			JMenuItem source = (JMenuItem)e.getSource();
			chooseColor = source.getText();
			int row = table.getSelectedRow();
			tableModel.setColor(row, chooseColor);
			tableModel.fireTableDataChanged();
		}
	}
}
