package gui.panels;

import gui.components.Label;
import gui.components.RadioButton;

import java.awt.FlowLayout;

import javax.swing.ButtonGroup;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextField;

import utils.Language;
import engine.Engine;

/**
 * Plot panel with additional components 
 * for specific options to plot frequency table.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class FreqPlotPanel extends PlotPanel{

	private static final long serialVersionUID = 1L;
	private static String[] opt = {"Nk", "Pk", "Pk[%]"};
	private RadioButton barPlot;
	private RadioButton piePlot;
	private ButtonGroup btnGroup;
	private Label lblXAxes;
	private Label lblYAxes;
	private JPanel btnPanel;
	private JTextField tfXAxes;
	private JTextField tfYAxes;
	private JPanel xAxesPanel;
	private JPanel yAxesPanel;
	private ChooseColorPanel colorPanel;
	private JComboBox<String> optBox;

	/**
	 * Create panel for plots of frequency table.
	 * 
	 * @param engine {@link Engine} - engine for data analyze
	 * @param lang {@link Language} - language for load labels
	 * @param parent JFrame - parent frame
	 * @param colName String - columns names
	 */
	public FreqPlotPanel(Engine engine, Language lang, JFrame parent, String ... colName) {
		super(engine, lang, parent, colName);
	}
	
	/**
	 * Create additional components.
	 */
	protected void createComponents() {
		btnPanel = new JPanel(new FlowLayout());
		
		barPlot = new RadioButton("LABEL_PLOT_BAR", language);
		addGuiObject(barPlot);
		barPlot.setSelected(true);
		piePlot = new RadioButton("LABEL_PLOT_PIE", language);
		addGuiObject(piePlot);
		btnGroup = new ButtonGroup();
		
		optBox = new JComboBox<String>(opt);
		
		btnGroup.add(barPlot);
		btnGroup.add(piePlot);
		
		lblXAxes = new Label("LABEL_PLOT_XAXE", language);
		addGuiObject(lblXAxes);
		lblYAxes = new Label("LABEL_PLOT_YAXE", language);
		addGuiObject(lblYAxes);
		
		btnPanel.add(barPlot);
		btnPanel.add(piePlot);
		btnPanel.add(optBox);
		
		tfXAxes = new JTextField(30);
		tfYAxes = new JTextField(30);
		
		xAxesPanel = new JPanel(new FlowLayout());
		xAxesPanel.add(lblXAxes);
		xAxesPanel.add(tfXAxes);

		yAxesPanel = new JPanel(new FlowLayout());
		yAxesPanel.add(lblYAxes);
		yAxesPanel.add(tfYAxes);
		
		String[] names = {"Categories", "Colors"};
		colorPanel = new ChooseColorPanel(engine.getCategories(colName[0]), names);
		
		add(btnPanel);
		add(xAxesPanel);
		add(yAxesPanel);
		add(colorPanel);
	}

	@Override
	protected boolean drawPlot() {
		engine.setColors(colorPanel.getColors());
		boolean contingency = colName.length > 1 ? true : false;
		
		switch (optBox.getSelectedIndex()) {
		case 0:
			if(contingency){
				engine.createBarPlot(Engine.PLOT_TYPES.ABS, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(barPlot.isSelected()){
				boolean status = engine.createHistogram(Engine.PLOT_TYPES.ABS, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName[0]);
				if(!status)	engine.createBarPlot(Engine.PLOT_TYPES.ABS, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(piePlot.isSelected()){
				engine.createPiePlot(Engine.PLOT_TYPES.ABS, tfTitle.getText(), colName[0]);
			}
			break;
		case 1:
			if(contingency){
				engine.createBarPlot(Engine.PLOT_TYPES.REL, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(barPlot.isSelected()){
				boolean status = engine.createHistogram(Engine.PLOT_TYPES.REL, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName[0]);
				if(!status)	engine.createBarPlot(Engine.PLOT_TYPES.REL, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(piePlot.isSelected()){
				engine.createPiePlot(Engine.PLOT_TYPES.REL, tfTitle.getText(), colName[0]);
			}
			break;
		case 2:
			if(contingency){
				engine.createBarPlot(Engine.PLOT_TYPES.REL100, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(barPlot.isSelected()){
				boolean status = engine.createHistogram(Engine.PLOT_TYPES.REL100, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName[0]);
				if(!status)	engine.createBarPlot(Engine.PLOT_TYPES.REL100, tfTitle.getText(), tfXAxes.getText(), tfYAxes.getText(), colName);
			}
			else if(piePlot.isSelected()){
				engine.createPiePlot(Engine.PLOT_TYPES.REL100, tfTitle.getText(), colName[0]);
			}
			break;
		default:
			break;
		}
		return true;
	}
	
	/**
	 * Set pie radio button to disable.
	 */
	public void setPieDisable(){
		piePlot.setEnabled(false);
	}
	
	/**
	 * Change categories names of table with colors.
	 * 
	 * @param data String - categories names
	 */
	public void fireDataList(String[] data){
		colorPanel.fireDataList(data);
		engine.changeCategoriesNames(data, colName[0]);
	}
}
