package model;

/**
 * Model class represented structure of data table.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public class Table {
	
	private int rowCount, colCount;
	private String[][] data;
	private String[] names;
	
	/**
	 * Create table with specific rows and cols.
	 * @param rows int - number of rows
	 * @param cols int - number of cols
	 */
	public Table(int rows, int cols){
		rowCount = rows;
		colCount = cols;
		data = new String[rows][cols];
	}
	
	/**
	 * Get columns names.
	 * 
	 * @return String -names of columns 
	 */
	public String[] getNames(){
		return names;
	}
	
	/**
	 * Get matrix from table.
	 * 
	 * @return data String[][] - matrix data
	 */
	public String[][] getData(){
		return data;
	}

	/**
	 * Set matrix to table.
	 * 
	 * @param newVal String[][] - matrix data
	 */
	public void setData(String[][] newVal){
		data = newVal;
	}

	/**
	 * Set names of columns.
	 * 
	 * @param newVal String[] - names of columns
	 */
	public void setNames(String[] newVal){
		names = newVal;
	}
	
	/**
	 * Set data to specific cell.
	 * 
	 * @param value String - data to save
	 * @param row int - row index
	 * @param col int - rol index
	 */
	public void setData(String value, int row, int col){
		data[row][col] = value; 
	}
	
	/**
	 * Return data from specific cell.
	 * 
	 * @param row int - row index
	 * @param col int - col index
	 * @return data String - data from cell
	 */
	public String getData(int row, int col){
		if("-2147483648".equals(data[row][col])){
			return "";
		}
		else{
			return data[row][col];
		}
	}
	
	/**
	 * Return number of all rows.
	 * 
	 * @return rowCount int - number of rows
	 */
	public int getRowCount() {
		return rowCount;
	}
	
	/**
	 * Return number of all columns.
	 * 
	 * @return colCount int - number of columns
	 */
	public int getColCount() {
		return colCount;
	}	
}