package utils;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

import javax.swing.JOptionPane;

import model.Table;

/**
 * Class with static methods for export data things.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 */
public class ExportUtils {

	/**
	 * Export specific table {@link Table} to specific file on hard drive.
	 * 
	 * @param table {@link Table} - specific table
	 * @param destination String - specific file destination path
	 * @return true if export was successful, false otherwise.
	 */
	public static boolean exportTableToCSV(Table table, String destination){		
		String data[][] = table.getData();
		String names[] = table.getNames();
		String result = "";		
		
		File dest = new File(destination+".csv");
		try {
			dest.createNewFile();
			BufferedWriter out = new BufferedWriter(new FileWriter(dest));
			out.write(result);
			
			for (int i = 0; i < names.length; i++) {
				result += names[i];
				if (i < names.length-1) {
					result += ";";
				}
			}
			out.write(result);
			out.newLine();
			
			for (int i = 0; i < table.getRowCount(); i++) {
				result = "";
				for (int j = 0; j < table.getColCount(); j++) {
					result += data[i][j];
					if (j < table.getColCount()-1) {
						result += ";";
					}
				}
				out.write(result);
				out.newLine();
			}
			
			out.close();
		} catch (IOException e) {
			JOptionPane.showMessageDialog(null, e.getMessage(), "Error", JOptionPane.ERROR_MESSAGE);
			return false;
		}
		
		return true;
	}

}