package utils;

import java.awt.BorderLayout;

import javax.swing.JComboBox;
import javax.swing.JComponent;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.filechooser.FileNameExtensionFilter;

import engine.Engine.FILE_TYPE;

/**
 * Class with static methods for file manipulations.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 *
 */
public class FileUtils {
	
	/**
	 * Show open dialog for load csv file.
	 * 
	 * @return object Object[] - array with CSV file and type of separator.
	 */
	public static Object[] showCSVOpenDialog(){
		JFileChooser fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
		fc.setMultiSelectionEnabled(false);
		fc.setAcceptAllFileFilterUsed(false);
		fc.addChoosableFileFilter(new FileNameExtensionFilter("CSV Files", "csv"));
		
		JComboBox<FILE_TYPE> cb = new JComboBox<FILE_TYPE>(FILE_TYPE.values());
		JComponent comp = ((JComponent)((JPanel)((JPanel)((JPanel)fc.getComponent(2)).getComponent(2)).getComponent(2)).getComponent(3));
		JPanel panel = new JPanel(new BorderLayout());
		panel.add(comp, BorderLayout.CENTER);
		panel.add(cb, BorderLayout.EAST);
		((JPanel)((JPanel)((JPanel)fc.getComponent(2)).getComponent(2)).getComponent(2)).add(panel, 3);

		int option = fc.showOpenDialog(null);
		
		if(option == JFileChooser.APPROVE_OPTION){
			return new Object[] {fc.getSelectedFile(), cb.getSelectedItem()};
		}
		
		return null;
	}
	
	/**
	 * Show dialog to save custom file.
	 * 
	 * @param description String - description of files types
	 * @param filesTypes String - filesTypes
	 * @return filePath String - absolute path to save file
	 */
	public static String showFileSaveDialog(String description, String ... filesTypes){
		JFileChooser fc = new JFileChooser();
		fc.setFileSelectionMode(JFileChooser.FILES_ONLY);
		fc.setAcceptAllFileFilterUsed(false);
		fc.addChoosableFileFilter(new FileNameExtensionFilter(description, filesTypes));
		
		int option = fc.showSaveDialog(null);
		
		if(option == JFileChooser.APPROVE_OPTION){
			return fc.getSelectedFile().getAbsolutePath();
		}
		
		return null;
	}
}
