package utils;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.util.Properties;

/**
 * Class with static methods for language files.
 * 
 * @author Pavel Vojtas
 * @version 1.0
 * 
 */
public class LanguageUtils {
	
	/**
	 * Open specific language file.
	 * 
	 * @param lang {@link Language} - specific language
	 * @return inputStream InputStream - stream of open file
	 * @throws FileNotFoundException - file doesn't exist
	 */
	public static InputStream openLangFile(Language lang) throws FileNotFoundException{
		InputStream input = null;
		if(lang == Language.CZECH){
			input = new FileInputStream("lang/czech.properties");
		}
		else if(lang == Language.ENGLISH){
			input = new FileInputStream("lang/english.properties");
		}
		
		return input;
	}
	
	/**
	 * Open config file and return his input stream
	 * 
	 * @return inputStream InputStream - stream of open file
	 * @throws FileNotFoundException - file doesn't exist
	 */
	public static InputStream openConfigFile() throws FileNotFoundException{
		return new FileInputStream("config.properties");
	}
	
	/**
	 * Load language settings from config file. If language option 
	 * is corrupted then return null.
	 * 
	 * @return language {@link Language}. 
	 * @throws IOException - exceptions in file
	 */
	public static Language getLanguage() throws IOException{
		Properties properties = new Properties();
		properties.load(LanguageUtils.openConfigFile());
		String lang = properties.getProperty("language");
		if(lang.equals("cs")) return Language.CZECH;
		if(lang.equals("en")) return Language.ENGLISH;
		
		return null;
	}
	
	/**
	 * Write specific setting option to config file.
	 * 
	 * @param property String - specific setting id
	 * @param value String - specific setting value
	 * @throws IOException - file exceptions
	 */
	public static void writeConfigFile(String property, String value) throws IOException{
		Properties properties = new Properties();
		OutputStream output = new FileOutputStream("config.properties");
		properties.setProperty(property, value);		
		properties.store(output, null);
	}

}